SchemaSpy - Table gnss_data.public.keys

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.keys | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
KeyCode | varchar | 7 |  |  |  |
rinex_tank_struct.KeyCode | rinex_tank_struct_key_fkey R
TotalChars | int4 | 10 | √ |  | null |  |  |
rinex_col_out | varchar | 2147483647 | √ |  | null |  |  |
rinex_col_in | varchar | 60 | √ |  | null |  |  |
isnumeric | bit | 1 | √ |  | null |  |  |
Table contained 7 rows at Fri Jul 28 14:55 EDT 2017

Close relationships: